@@ -1,92 +1,108 @@
-import unittest
-import subprocess
 import os
+import unittest
+from pathlib import Path
+
+import pytest
+
+from . import run_ansible_lint
 
 
 class TestCliRolePaths(unittest.TestCase):
     def setUp(self):
         self.local_test_dir = os.path.dirname(os.path.realpath(__file__))
 
-    def run_ansible_lint(self, cwd, bin, role_path, env=None):
-        command = '{} {}'.format(bin, role_path)
-
-        result, err = subprocess.Popen(
-            [command],
-            cwd=cwd,
-            stdin=subprocess.PIPE,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-            shell=True,
-            env=env,
-        ).communicate()
-
-        self.assertFalse(err, 'Expected no error but was ' + str(err))
-
-        return result
-
-    def test_run_single_role_path_no_trailing_slash(self):
+    def test_run_single_role_path_no_trailing_slash_module(self):
         cwd = self.local_test_dir
-        bin = '../bin/ansible-lint'
         role_path = 'test-role'
 
-        result = self.run_ansible_lint(cwd=cwd, bin=bin, role_path=role_path)
+        result = run_ansible_lint(cwd=cwd, role_path=role_path)
+        self.assertIn('Use shell only when shell functionality is required',
+                      str(result))
+
+    def test_run_single_role_path_no_trailing_slash_script(self):
+        cwd = self.local_test_dir
+        role_path = 'test-role'
+
+        result = run_ansible_lint(cwd=cwd, role_path=role_path, bin="ansible-lint")
         self.assertIn('Use shell only when shell functionality is required',
                       str(result))
 
     def test_run_single_role_path_with_trailing_slash(self):
         cwd = self.local_test_dir
-        bin = '../bin/ansible-lint'
         role_path = 'test-role/'
 
-        result = self.run_ansible_lint(cwd=cwd, bin=bin, role_path=role_path)
+        result = run_ansible_lint(cwd=cwd, role_path=role_path)
         self.assertIn('Use shell only when shell functionality is required',
                       str(result))
 
     def test_run_multiple_role_path_no_trailing_slash(self):
         cwd = self.local_test_dir
-        bin = '../bin/ansible-lint'
         role_path = 'roles/test-role'
 
-        result = self.run_ansible_lint(cwd=cwd, bin=bin, role_path=role_path)
+        result = run_ansible_lint(cwd=cwd, role_path=role_path)
         self.assertIn('Use shell only when shell functionality is required',
                       str(result))
 
     def test_run_multiple_role_path_with_trailing_slash(self):
         cwd = self.local_test_dir
-        bin = '../bin/ansible-lint'
         role_path = 'roles/test-role/'
 
-        result = self.run_ansible_lint(cwd=cwd, bin=bin, role_path=role_path)
+        result = run_ansible_lint(cwd=cwd, role_path=role_path)
         self.assertIn('Use shell only when shell functionality is required',
                       str(result))
 
     def test_run_inside_role_dir(self):
         cwd = os.path.join(self.local_test_dir, 'test-role/')
-        bin = '../../bin/ansible-lint'
         role_path = '.'
 
-        result = self.run_ansible_lint(cwd=cwd, bin=bin, role_path=role_path)
+        result = run_ansible_lint(cwd=cwd, role_path=role_path)
         self.assertIn('Use shell only when shell functionality is required',
                       str(result))
 
     def test_run_role_three_dir_deep(self):
         cwd = self.local_test_dir
-        bin = '../bin/ansible-lint'
         role_path = 'testproject/roles/test-role'
 
-        result = self.run_ansible_lint(cwd=cwd, bin=bin, role_path=role_path)
+        result = run_ansible_lint(cwd=cwd, role_path=role_path)
         self.assertIn('Use shell only when shell functionality is required',
                       str(result))
 
     def test_run_playbook(self):
-        '''Call ansible-lint the way molecule does'''
+        """Call ansible-lint the way molecule does."""
         top_src_dir = os.path.dirname(self.local_test_dir)
         cwd = os.path.join(top_src_dir, 'test/roles/test-role')
-        bin = top_src_dir + '/bin/ansible-lint'
         role_path = 'molecule/default/include-import-role.yml'
 
         env = os.environ.copy()
         env['ANSIBLE_ROLES_PATH'] = os.path.dirname(cwd)
 
-        result = self.run_ansible_lint(cwd=cwd, bin=bin, role_path=role_path, env=env)
+        result = run_ansible_lint(cwd=cwd, role_path=role_path, env=env)
         self.assertIn('Use shell only when shell functionality is required', str(result))
+
+    def test_run_role_name_invalid(self):
+        cwd = self.local_test_dir
+        role_path = 'roles/invalid-name'
+
+        result = run_ansible_lint(cwd=cwd, role_path=role_path)
+        assert '106 Role name invalid-name does not match' in str(result)
+
+
+@pytest.mark.parametrize(('result', 'env'), (
+    (True, {
+        "GITHUB_ACTIONS": "true",
+        "GITHUB_WORKFLOW": "foo"
+    }),
+    (False, None)),
+    ids=("on", "off"))
+def test_run_playbook_github(result, env):
+    """Call ansible-lint simulating GitHub Actions environment."""
+    cwd = str(Path(__file__).parent.parent.resolve())
+    role_path = 'examples/example.yml'
+
+    result_gh = run_ansible_lint(cwd=cwd, role_path=role_path, env=env)
+
+    expected = (
+        '::error file=examples/example.yml,line=47::[E101] '
+        'Deprecated always_run'
+    )
+    assert (expected in str(result_gh)) is result
