@@ -1,6 +1,8 @@
 import unittest
-from ansiblelint import RulesCollection, Runner
+
+from ansiblelint.rules import RulesCollection
 from ansiblelint.rules.TrailingWhitespaceRule import TrailingWhitespaceRule
+from ansiblelint.runner import Runner
 
 
 class TestWithSkipTagId(unittest.TestCase):
